@@ -83,6 +83,17 @@ class K8sClusterProxy(base.BaseProxy):
         persistent_storage_nimble_csi=False,
         addons=[],
         external_identity_server={},
+        ext_id_svr_bind_pwd=None,
+        ext_id_svr_user_attribute=None,
+        ext_id_svr_bind_type=None,
+        ext_id_svr_bind_dn=None,
+        ext_id_svr_host=None,
+        ext_id_svr_group_attribute=None,
+        ext_id_svr_security_protocol=None,
+        ext_id_svr_base_dn=None,
+        ext_id_svr_verify_peer=None,
+        ext_id_svr_type=None,
+        ext_id_svr_port=None,
         external_groups=[],
         datafabric=False,
         datafabric_name=None,
@@ -103,9 +114,8 @@ class K8sClusterProxy(base.BaseProxy):
         :param persistent_storage_nimble_csi: True/False
         :param addons: list of required addons. See:
             `hpecp k8scluster get-available-addons`
-        :param external_identity_server: dict
-           Example {
-                "bind_pwd":"password",
+        :param external_identity_server: dict (deprecated)
+           Example '{"bind_pwd":"password",
                 "user_attribute":"CN",
                 "bind_type":"search_bind",
                 "bind_dn":"cn=Administrator,CN=Users,DC=samdom,DC=example,DC=com",
@@ -115,7 +125,18 @@ class K8sClusterProxy(base.BaseProxy):
                 "base_dn":"CN=Users,DC=samdom,DC=example,DC=com",
                 "verify_peer":false,
                 "type":"Active Directory",
-                "port":636}
+                "port":636}'
+        :param ext_id_svr_bind_pwd str
+        :param ext_id_svr_user_attribute str
+        :param ext_id_svr_bind_type str
+        :param ext_id_svr_bind_dn str
+        :param ext_id_svr_host str
+        :param ext_id_svr_group_attribute str
+        :param ext_id_svr_security_protocol str
+        :param ext_id_svr_base_dn str
+        :param ext_id_svr_verify_peer bool
+        :param ext_id_svr_type str
+        :param ext_id_svr_port int
         """
         host_config = [
             K8sClusterHostConfig.create_from_list(h.split(":"))
@@ -123,17 +144,59 @@ class K8sClusterProxy(base.BaseProxy):
         ]
 
         if external_identity_server:
-            try:
-                external_identity_server = json.loads(external_identity_server)
-            except ValueError:
+            if not isinstance(external_identity_server, dict):
                 print(
                     (
-                        "could not parse 'external_identity_server' parameter"
-                        " - is it valid json?"
+                        "Could not parse 'external_identity_server' parameter"
+                        " - is it valid json?\n"
+                        "Received: " + external_identity_server + "\n"
                     ),
                     file=sys.stderr,
                 )
                 sys.exit(1)
+        else:
+            external_identity_server = {}
+
+        if ext_id_svr_bind_pwd is not None:
+            external_identity_server["bind_pwd"] = ext_id_svr_bind_pwd
+
+        if ext_id_svr_user_attribute is not None:
+            external_identity_server[
+                "user_attribute"
+            ] = ext_id_svr_user_attribute
+
+        if ext_id_svr_bind_type is not None:
+            external_identity_server["bind_type"] = ext_id_svr_bind_type
+
+        if ext_id_svr_bind_dn is not None:
+            external_identity_server["bind_dn"] = ext_id_svr_bind_dn
+
+        if ext_id_svr_host is not None:
+            external_identity_server["host"] = ext_id_svr_host
+
+        if ext_id_svr_group_attribute is not None:
+            external_identity_server[
+                "group_attribute"
+            ] = ext_id_svr_group_attribute
+
+        if ext_id_svr_security_protocol is not None:
+            external_identity_server[
+                "security_protocol"
+            ] = ext_id_svr_security_protocol
+
+        if ext_id_svr_base_dn is not None:
+            external_identity_server["base_dn"] = ext_id_svr_base_dn
+
+        if ext_id_svr_verify_peer is not None:
+            external_identity_server["verify_peer"] = json.loads(
+                ext_id_svr_verify_peer.lower()
+            )
+
+        if ext_id_svr_type is not None:
+            external_identity_server["svr_type"] = ext_id_svr_type
+
+        if ext_id_svr_port is not None:
+            external_identity_server["svr_port"] = int(ext_id_svr_port)
 
         print(
             base.get_client().k8s_cluster.create(
